==> jena-5.4.0-source-release.zip: jena-5.4.0/jena-permissions/src/test/java/org/apache/jena/permissions/contract/graph/SecuredTDBGraphContractTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jena.permissions.contract.graph;

import org.apache.jena.graph.Graph;
import org.apache.jena.graph.test.MetaTestGraph;
import org.apache.jena.permissions.MockSecurityEvaluator;
import org.apache.jena.permissions.SecurityEvaluator;
import org.apache.jena.tdb1.TDB1Factory;

public class SecuredTDBGraphContractTests extends MetaTestGraph {

    private final SecurityEvaluator eval;

    public SecuredTDBGraphContractTests(final Class<? extends Graph> graphClass, final String name) {
        super(graphClass, name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    public SecuredTDBGraphContractTests(final String name) {
        super(name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    @Override
    public Graph getGraph() {
        return org.apache.jena.permissions.Factory.getInstance(eval, getName(),
                TDB1Factory.createDatasetGraph().getDefaultGraph());
    }

}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-permissions/src/test/java/org/apache/jena/permissions/contract/graph/SecuredTDBGraphContractTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jena.permissions.contract.graph;

import org.apache.jena.graph.Graph;
import org.apache.jena.graph.test.MetaTestGraph;
import org.apache.jena.permissions.MockSecurityEvaluator;
import org.apache.jena.permissions.SecurityEvaluator;
import org.apache.jena.tdb1.TDB1Factory;

@SuppressWarnings("removal")
public class SecuredTDBGraphContractTests extends MetaTestGraph {

    private final SecurityEvaluator eval;

    public SecuredTDBGraphContractTests(final Class<? extends Graph> graphClass, final String name) {
        super(graphClass, name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    public SecuredTDBGraphContractTests(final String name) {
        super(name);
        eval = new MockSecurityEvaluator(true, true, true, true, true, true, true);
    }

    @Override
    public Graph getNewGraph() {
        return org.apache.jena.permissions.Factory.getInstance(eval, getName(),
                TDB1Factory.createDatasetGraph().getDefaultGraph());
    }
}
